==> tekton-model-triggers-v1alpha1-6.2.0-sources.jar: io/fabric8/tekton/triggers/v1alpha1/ResourcesFluent.java <==
package io.fabric8.tekton.triggers.v1alpha1;

import io.fabric8.kubernetes.api.builder.Nested;
import io.fabric8.kubernetes.api.model.PersistentVolumeClaimFluent;
import java.lang.Deprecated;
import java.lang.Boolean;
import io.fabric8.kubernetes.api.model.HasMetadata;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.model.PersistentVolumeClaimBuilder;
import io.fabric8.kubernetes.api.model.PersistentVolumeClaim;

 /**
  * Generated
  */
public interface ResourcesFluent<A extends ResourcesFluent<A>> extends Fluent<A>{
  
  /**
   * This method has been deprecated, please use method buildCustomResource instead.
   * @return The buildable object.
   */
  @Deprecated
  public HasMetadata getCustomResource();
  public HasMetadata buildCustomResource();
  public A withCustomResource(HasMetadata customResource);
  public Boolean hasCustomResource();
  public A withTriggerTemplateCustomResource(TriggerTemplate triggerTemplateCustomResource);
  public ResourcesFluent.TriggerTemplateCustomResourceNested<A> withNewTriggerTemplateCustomResource();
  public ResourcesFluent.TriggerTemplateCustomResourceNested<A> withNewTriggerTemplateCustomResourceLike(TriggerTemplate item);
  public A withClusterInterceptorCustomResource(ClusterInterceptor clusterInterceptorCustomResource);
  public ResourcesFluent.ClusterInterceptorCustomResourceNested<A> withNewClusterInterceptorCustomResource();
  public ResourcesFluent.ClusterInterceptorCustomResourceNested<A> withNewClusterInterceptorCustomResourceLike(ClusterInterceptor item);
  public A withTriggerBindingCustomResource(TriggerBinding triggerBindingCustomResource);
  public ResourcesFluent.TriggerBindingCustomResourceNested<A> withNewTriggerBindingCustomResource();
  public ResourcesFluent.TriggerBindingCustomResourceNested<A> withNewTriggerBindingCustomResourceLike(TriggerBinding item);
  public A withClusterTriggerBindingCustomResource(ClusterTriggerBinding clusterTriggerBindingCustomResource);
  public ResourcesFluent.ClusterTriggerBindingCustomResourceNested<A> withNewClusterTriggerBindingCustomResource();
  public ResourcesFluent.ClusterTriggerBindingCustomResourceNested<A> withNewClusterTriggerBindingCustomResourceLike(ClusterTriggerBinding item);
  public A withPersistentVolumeClaimCustomResource(PersistentVolumeClaim persistentVolumeClaimCustomResource);
  public ResourcesFluent.PersistentVolumeClaimCustomResourceNested<A> withNewPersistentVolumeClaimCustomResource();
  public ResourcesFluent.PersistentVolumeClaimCustomResourceNested<A> withNewPersistentVolumeClaimCustomResourceLike(PersistentVolumeClaim item);
  public A withEventListenerCustomResource(EventListener eventListenerCustomResource);
  public ResourcesFluent.EventListenerCustomResourceNested<A> withNewEventListenerCustomResource();
  public ResourcesFluent.EventListenerCustomResourceNested<A> withNewEventListenerCustomResourceLike(EventListener item);
  public A withTriggerCustomResource(Trigger triggerCustomResource);
  public ResourcesFluent.TriggerCustomResourceNested<A> withNewTriggerCustomResource();
  public ResourcesFluent.TriggerCustomResourceNested<A> withNewTriggerCustomResourceLike(Trigger item);
  
  /**
   * This method has been deprecated, please use method buildKubernetesResource instead.
   * @return The buildable object.
   */
  @Deprecated
  public KubernetesResource getKubernetesResource();
  public KubernetesResource buildKubernetesResource();
  public A withKubernetesResource(KubernetesResource kubernetesResource);
  public Boolean hasKubernetesResource();
  public ResourcesFluent.KubernetesResourceNested<A> withNewKubernetesResource();
  public ResourcesFluent.KubernetesResourceNested<A> withNewKubernetesResourceLike(KubernetesResource item);
  public ResourcesFluent.KubernetesResourceNested<A> editKubernetesResource();
  public ResourcesFluent.KubernetesResourceNested<A> editOrNewKubernetesResource();
  public ResourcesFluent.KubernetesResourceNested<A> editOrNewKubernetesResourceLike(KubernetesResource item);
  public interface TriggerTemplateCustomResourceNested<N> extends Nested<N>,TriggerTemplateFluent<ResourcesFluent.TriggerTemplateCustomResourceNested<N>>{
    public N and();
    public N endTriggerTemplateCustomResource();
    
  }
  public interface ClusterInterceptorCustomResourceNested<N> extends Nested<N>,ClusterInterceptorFluent<ResourcesFluent.ClusterInterceptorCustomResourceNested<N>>{
    public N and();
    public N endClusterInterceptorCustomResource();
    
  }
  public interface TriggerBindingCustomResourceNested<N> extends Nested<N>,TriggerBindingFluent<ResourcesFluent.TriggerBindingCustomResourceNested<N>>{
    public N and();
    public N endTriggerBindingCustomResource();
    
  }
  public interface ClusterTriggerBindingCustomResourceNested<N> extends Nested<N>,ClusterTriggerBindingFluent<ResourcesFluent.ClusterTriggerBindingCustomResourceNested<N>>{
    public N and();
    public N endClusterTriggerBindingCustomResource();
    
  }
  public interface PersistentVolumeClaimCustomResourceNested<N> extends Nested<N>,PersistentVolumeClaimFluent<ResourcesFluent.PersistentVolumeClaimCustomResourceNested<N>>{
    public N and();
    public N endPersistentVolumeClaimCustomResource();
    
  }
  public interface EventListenerCustomResourceNested<N> extends Nested<N>,EventListenerFluent<ResourcesFluent.EventListenerCustomResourceNested<N>>{
    public N and();
    public N endEventListenerCustomResource();
    
  }
  public interface TriggerCustomResourceNested<N> extends Nested<N>,TriggerFluent<ResourcesFluent.TriggerCustomResourceNested<N>>{
    public N and();
    public N endTriggerCustomResource();
    
  }
  public interface KubernetesResourceNested<N> extends Nested<N>,KubernetesResourceFluent<ResourcesFluent.KubernetesResourceNested<N>>{
    public N and();
    public N endKubernetesResource();
    
  }
  
}

==> tekton-model-triggers-v1alpha1-6.6.1-sources.jar: io/fabric8/tekton/triggers/v1alpha1/ResourcesFluent.java <==
package io.fabric8.tekton.triggers.v1alpha1;

import io.fabric8.kubernetes.api.builder.Nested;
import io.fabric8.kubernetes.api.model.PersistentVolumeClaimFluent;
import io.fabric8.kubernetes.api.model.GenericKubernetesResource;
import java.lang.Deprecated;
import java.lang.Boolean;
import io.fabric8.kubernetes.api.model.HasMetadata;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.model.PersistentVolumeClaimBuilder;
import io.fabric8.kubernetes.api.model.GenericKubernetesResourceBuilder;
import io.fabric8.kubernetes.api.model.GenericKubernetesResourceFluent;
import io.fabric8.kubernetes.api.model.PersistentVolumeClaim;

 /**
  * Generated
  */
public interface ResourcesFluent<A extends ResourcesFluent<A>> extends Fluent<A>{
  
  /**
   * This method has been deprecated, please use method buildCustomResource instead.
   * @return The buildable object.
   */
  @Deprecated
  public HasMetadata getCustomResource();
  public HasMetadata buildCustomResource();
  public A withCustomResource(HasMetadata customResource);
  public Boolean hasCustomResource();
  public A withTriggerTemplateCustomResource(TriggerTemplate triggerTemplateCustomResource);
  public ResourcesFluent.TriggerTemplateCustomResourceNested<A> withNewTriggerTemplateCustomResource();
  public ResourcesFluent.TriggerTemplateCustomResourceNested<A> withNewTriggerTemplateCustomResourceLike(TriggerTemplate item);
  public A withClusterInterceptorCustomResource(ClusterInterceptor clusterInterceptorCustomResource);
  public ResourcesFluent.ClusterInterceptorCustomResourceNested<A> withNewClusterInterceptorCustomResource();
  public ResourcesFluent.ClusterInterceptorCustomResourceNested<A> withNewClusterInterceptorCustomResourceLike(ClusterInterceptor item);
  public A withTriggerBindingCustomResource(TriggerBinding triggerBindingCustomResource);
  public ResourcesFluent.TriggerBindingCustomResourceNested<A> withNewTriggerBindingCustomResource();
  public ResourcesFluent.TriggerBindingCustomResourceNested<A> withNewTriggerBindingCustomResourceLike(TriggerBinding item);
  public A withClusterTriggerBindingCustomResource(ClusterTriggerBinding clusterTriggerBindingCustomResource);
  public ResourcesFluent.ClusterTriggerBindingCustomResourceNested<A> withNewClusterTriggerBindingCustomResource();
  public ResourcesFluent.ClusterTriggerBindingCustomResourceNested<A> withNewClusterTriggerBindingCustomResourceLike(ClusterTriggerBinding item);
  public A withPersistentVolumeClaimCustomResource(PersistentVolumeClaim persistentVolumeClaimCustomResource);
  public ResourcesFluent.PersistentVolumeClaimCustomResourceNested<A> withNewPersistentVolumeClaimCustomResource();
  public ResourcesFluent.PersistentVolumeClaimCustomResourceNested<A> withNewPersistentVolumeClaimCustomResourceLike(PersistentVolumeClaim item);
  public A withGenericKubernetesResourceCustom(GenericKubernetesResource genericKubernetesResourceCustom);
  public ResourcesFluent.GenericKubernetesResourceCustomNested<A> withNewGenericKubernetesResourceCustom();
  public ResourcesFluent.GenericKubernetesResourceCustomNested<A> withNewGenericKubernetesResourceCustomLike(GenericKubernetesResource item);
  public A withEventListenerCustomResource(EventListener eventListenerCustomResource);
  public ResourcesFluent.EventListenerCustomResourceNested<A> withNewEventListenerCustomResource();
  public ResourcesFluent.EventListenerCustomResourceNested<A> withNewEventListenerCustomResourceLike(EventListener item);
  public A withTriggerCustomResource(Trigger triggerCustomResource);
  public ResourcesFluent.TriggerCustomResourceNested<A> withNewTriggerCustomResource();
  public ResourcesFluent.TriggerCustomResourceNested<A> withNewTriggerCustomResourceLike(Trigger item);
  
  /**
   * This method has been deprecated, please use method buildKubernetesResource instead.
   * @return The buildable object.
   */
  @Deprecated
  public KubernetesResource getKubernetesResource();
  public KubernetesResource buildKubernetesResource();
  public A withKubernetesResource(KubernetesResource kubernetesResource);
  public Boolean hasKubernetesResource();
  public ResourcesFluent.KubernetesResourceNested<A> withNewKubernetesResource();
  public ResourcesFluent.KubernetesResourceNested<A> withNewKubernetesResourceLike(KubernetesResource item);
  public ResourcesFluent.KubernetesResourceNested<A> editKubernetesResource();
  public ResourcesFluent.KubernetesResourceNested<A> editOrNewKubernetesResource();
  public ResourcesFluent.KubernetesResourceNested<A> editOrNewKubernetesResourceLike(KubernetesResource item);
  public interface TriggerTemplateCustomResourceNested<N> extends Nested<N>,TriggerTemplateFluent<ResourcesFluent.TriggerTemplateCustomResourceNested<N>>{
    public N and();
    public N endTriggerTemplateCustomResource();
    
  }
  public interface ClusterInterceptorCustomResourceNested<N> extends Nested<N>,ClusterInterceptorFluent<ResourcesFluent.ClusterInterceptorCustomResourceNested<N>>{
    public N and();
    public N endClusterInterceptorCustomResource();
    
  }
  public interface TriggerBindingCustomResourceNested<N> extends Nested<N>,TriggerBindingFluent<ResourcesFluent.TriggerBindingCustomResourceNested<N>>{
    public N and();
    public N endTriggerBindingCustomResource();
    
  }
  public interface ClusterTriggerBindingCustomResourceNested<N> extends Nested<N>,ClusterTriggerBindingFluent<ResourcesFluent.ClusterTriggerBindingCustomResourceNested<N>>{
    public N and();
    public N endClusterTriggerBindingCustomResource();
    
  }
  public interface PersistentVolumeClaimCustomResourceNested<N> extends Nested<N>,PersistentVolumeClaimFluent<ResourcesFluent.PersistentVolumeClaimCustomResourceNested<N>>{
    public N and();
    public N endPersistentVolumeClaimCustomResource();
    
  }
  public interface GenericKubernetesResourceCustomNested<N> extends Nested<N>,GenericKubernetesResourceFluent<ResourcesFluent.GenericKubernetesResourceCustomNested<N>>{
    public N and();
    public N endGenericKubernetesResourceCustom();
    
  }
  public interface EventListenerCustomResourceNested<N> extends Nested<N>,EventListenerFluent<ResourcesFluent.EventListenerCustomResourceNested<N>>{
    public N and();
    public N endEventListenerCustomResource();
    
  }
  public interface TriggerCustomResourceNested<N> extends Nested<N>,TriggerFluent<ResourcesFluent.TriggerCustomResourceNested<N>>{
    public N and();
    public N endTriggerCustomResource();
    
  }
  public interface KubernetesResourceNested<N> extends Nested<N>,KubernetesResourceFluent<ResourcesFluent.KubernetesResourceNested<N>>{
    public N and();
    public N endKubernetesResource();
    
  }
  
}
